@@ -11,7 +11,7 @@
 #'        with or without standard-values and significance stars}
 #' } 
 #'
-#'Two estimators are available: the Engle-Granger two step
+#'Two estimators are available: the Engle-Granger two-steps
 #'approach (\code{2OLS}) or the Johansen (\code{ML}). For the 2OLS,
 #'deterministic regressors (or external variables if \code{LRinclude} is of
 #'class numeric) can be added for the estimation of the cointegrating value and
@@ -265,6 +265,7 @@ lineVar<-function(data, lag, r=1,include = c( "const", "trend","none", "both"),
       ve_no<-apply(ve,2, function(x) x/sqrt(t(x)%*%S11%*%x))
       ve_2<-t(t(ve_no)/diag(ve_no)) 
       ve_3<-ve_2[,1:r, drop=FALSE]
+      ## Phillips triangular normalisation (Juselius (2006, p. 216))
       C2 <- matrix(0, nrow = nrow(ve_2) - r, ncol = r)
       C <- rbind(diag(r), C2)
       ve_4 <- ve_3 %*% solve(t(C) %*% ve_3)
@@ -298,12 +299,11 @@ lineVar<-function(data, lag, r=1,include = c( "const", "trend","none", "both"),
     Z<-cbind(ECTminus1,Z)
   }#end model=="VECM"&estim=="ML"
 
-
 ###Slope parameters, residuals and fitted
-#   B<-t(Y)%*%Z%*%solve(t(Z)%*%Z)		#B: OLS parameters, dim 2 x npar
-  B<- t(qr.coef(qr(Z),Y))
-  fitted<-Z%*%t(B)
-  res<-Y-fitted
+  lmReg <- lm.fit(Z,Y) 
+  B <- t(lmReg$coefficients )
+  fitted <- lmReg$fitted.values 
+  res <- lmReg$residuals
 
 ###naming of variables and parameters
   npar<-ncol(B)*nrow(B)
@@ -367,7 +367,8 @@ lineVar<-function(data, lag, r=1,include = c( "const", "trend","none", "both"),
           df.residual=t-npar/k, 
           exogen = !is.null(exogen),
           num_exogen = if(!is.null(exogen)) NCOL(exogen) else 0,
-          model.specific=model.specific)
+          model.specific=model.specific,
+          qr=lmReg$qr)
   if(model=="VAR"){
     class(z)<-c("VAR","nlVar")
   } else {
@@ -386,13 +387,13 @@ lineVar<-function(data, lag, r=1,include = c( "const", "trend","none", "both"),
 
 #' Estimation of Vector error correction model (VECM)
 #'
-#' Estimate either a VECM by Engle-Granger or Johansen (MLE) method.
+#' Estimate a VECM by either Engle-Granger (2OLS) or Johansen (MLE) method.
 #'
 #' This function is just a wrapper for the \code{\link{lineVar}}, with
 #' model="VECM".
 #'
-#' More comprehensive functions for VECM are in package \pkg{vars}. A few
-#' differences appear in the VECM estimation: \describe{ \item{Engle-Granger
+#' More comprehensive functions for VECM are in package \pkg{vars}. 
+#' Differences with that package are: \describe{ \item{Engle-Granger
 #' estimator}{The Engle-Granger estimator is available}
 #' \item{Presentation}{Results are printed in a different ways, using a matrix
 #' form} \item{lateX export}{The matrix of coefficients can be exported to
@@ -412,7 +413,7 @@ lineVar<-function(data, lag, r=1,include = c( "const", "trend","none", "both"),
 #' Note that the lag specification corresponds to the lags in the VECM
 #' representation, not in the VAR (as is done in package vars or software
 #' GRETL). Basically, a VAR with 2 lags corresponds here to a VECM with 1 lag.
-#' Lag 0 in the VECM is not allowed.
+#' The lag can be set to 0, although some methods (irf, fevd) won't work for this case.
 #' 
 #' #'The arg \code{beta} allows to specify constrained cointegrating values, leading to
 #' \eqn{ECT= \beta^{'}X_{t-1}}. It should be specified as a \eqn{K \times r} matrix. In case of
@@ -423,6 +424,9 @@ lineVar<-function(data, lag, r=1,include = c( "const", "trend","none", "both"),
 #' the coefficients (eventually except for special case of r=1 and k-1), if you want to provide only part of the 
 #' parameters, and let the others be estimated, look at the functions in package urca. 
 #'
+#'The eigenvector matrix \eqn{\beta} is normalised using the Phillips triangular representation, 
+#'see Hamilton (1994, p. 576) and Juselius (2006, p. 216), see \code{\link{coefA}} for more details. 
+#'
 #' @param data multivariate time series (first row being first=oldest value)
 #' @param lag Number of lags (in the VECM representation, see Details)
 #' @param r Number of cointegrating relationships
@@ -436,6 +440,7 @@ lineVar<-function(data, lag, r=1,include = c( "const", "trend","none", "both"),
 #'@param exogen Inclusion of exogenous variables (first row being first=oldest
 #'value). Is either of same size than data (then automatically cut) or than
 #'end-sample.
+#'
 #'@return An object of class \code{VECM} (and higher classes \code{VAR} and
 #'\code{nlVar}) with methods: \describe{ \item{Usual methods}{Print, summary,
 #'plot, residuals, fitted, vcov} \item{Fit criteria}{AIC, BIC,
@@ -444,8 +449,17 @@ lineVar<-function(data, lag, r=1,include = c( "const", "trend","none", "both"),
 #'\code{\link{predict_rolling}}} \item{VAR/VECM methods}{Impulse response
 #'function (\code{\link[=irf.nlVar]{irf}}) and forecast error variance
 #'decomposition (\code{\link[=fevd.nlVar]{fevd}})} \item{LaTeX}{toLatex} }
+#'
 #'@author Matthieu Stigler
-#'@seealso \code{\link{lineVar}} \code{\link{TVAR}} and \code{\link{TVECM}} for
+#'
+#'@references
+#' Hamilton (1994) Time Series Analysis, Princeton University Press
+#' 
+#' Juselius (2006) The Cointegrated VAR model, Oxford University Press
+#'@seealso \code{\link{coefA}}, \code{\link{coefB}} and \code{\link{coefPi}} 
+#'to extract the relevant parameter matrices. 
+#'
+#'\code{\link{lineVar}} \code{\link{TVAR}} and \code{\link{TVECM}} for
 #'the correspoding threshold models. \code{\link{linear}} for the univariate AR
 #'model.
 #'@keywords ts
@@ -528,30 +542,38 @@ summary.VAR<-function(object, digits=4,...){
   t<-x$t
   k<-x$k
   Sigma<-matrix(1/(object$df.residual)*crossprod(x$residuals),ncol=k)
+  betas <- x$coefficients 
   XX <- crossprod(x$model.x)
-  cov.unscaled <- try(solve(XX), silent=TRUE)
+  # cov.unscaled <- try(solve(XX), silent=TRUE)
+  cov.unscaled <- chol2inv(object$qr$qr)
   if(inherits(cov.unscaled, "try-error")) {
     Qr <- qr(x$model.x)
     p1 <- 1:Qr$rank
     cov.unscaled <- chol2inv(Qr$qr[p1, p1, drop = FALSE])
     warning("Potential numerical unstability, beware of standard errors\n")
   }
-  VarCovB<-cov.unscaled%x%Sigma
-  StDevB<-matrix(sqrt(diag(VarCovB)), nrow=k)
-  Tvalue<-x$coefficients/StDevB
+  VarCovB <- Sigma %x% cov.unscaled
+  StDevB<-matrix(sqrt(diag(VarCovB)), nrow=k, byrow = TRUE)
+  Tvalue<-betas/StDevB
   
-  Pval<-pt(abs(Tvalue), df=(nrow(x$model.x)-ncol(x$model.x)), lower.tail=FALSE)+pt(-abs(Tvalue), df=(nrow(x$model.x)-ncol(x$model.x)), lower.tail=TRUE)
-	#Pval<-round(Pval,4)
+  Pval <- 2* pt(abs(Tvalue), df=x$df.residual, lower.tail=FALSE)
   symp <- symnum(Pval, corr=FALSE,cutpoints = c(0,  .001,.01,.05, .1, 1), symbols = c("***","** ","*  ",".  ","    "))
   stars<-matrix(symp, nrow=nrow(Pval))
-  ab<-matrix(paste(myformat(x$coefficients,digits),"(", myformat(StDevB,digits),")",stars,sep=""), nrow=nrow(Pval))
-  dimnames(ab)<-dimnames(x$coefficients)		
+  ab<-matrix(paste(myformat(betas,digits),"(", myformat(StDevB,digits),")",stars,sep=""), nrow=nrow(Pval))
+  dimnames(ab)<-dimnames(betas)		
 
+  ## assemble
+  coMat <- cbind(ct(betas), ct(StDevB), ct(Tvalue), ct(Pval))
+  colnames(coMat) <- c("Estimate", "Std. Error", "t value", "Pr(>|t|)")
+  rownames(coMat) <- paste(rep(eqNames(x), each=ncol(betas)), 
+                           gsub(" ", "", colnames(betas)), sep=":")
+  
   x$bigcoefficients<-ab
   x$cov.unscaled<-cov.unscaled
   x$sigma<-Sigma
   x$StDev<-StDevB
   x$Pvalues<-Pval
+  x$coefMat <- coMat
   x$stars<-stars
   x$starslegend<-symp
   x$aic<-AIC.nlVar(x)
@@ -580,9 +602,9 @@ print.summary.VAR<-function(x,...){
 #' @S3method vcov VAR
 vcov.VAR<-function(object, ...){
   sum<-summary.VAR(object)
-  so<-sum$cov.unscaled%x%sum$sigma
+  so<-sum$sigma %x% sum$cov.unscaled
   co.names<-gsub(" ", "", colnames(coef(object)))
-  eq.names<-gsub("Equation ", "",rownames(coef(object)))
+  eq.names <- eqNames(object)
   together.names<-paste(rep(eq.names,each= length(co.names)), co.names, sep=":")
   dimnames(so)<-list(together.names, together.names)
   so
