@@ -68,6 +68,9 @@ AIC(tvar)
 BIC(tvar)
 coef(tvar)
 deviance(tvar)
+vcov(tvar)
+df.residual(tvar)
+all.equal(summary(tvar)$VarCov[[1]], vcov(tvar))
 head(residuals(tvar))
 tail(residuals(tvar))
 head(fitted(tvar))
